## High level api code for icd10 search

Syntax:

```python
from dbaicd10.search import ICD10
i = ICD10()
i.search("tennis elbow")
```

#### This lib provides two functions

1. ICD10.search("query")

2. ICD10.auto_correct("query")

Please refer to python docstring for more details.